# Expressions

Expression context, type aliases, and built-in expression helpers.

## ExpressionContext

::: pymotion.expressions.ExpressionContext

## ExpressionFn

::: pymotion.expressions.ExpressionFn

## evaluate_expressions

::: pymotion.expressions.evaluate_expressions

## wiggle

::: pymotion.expressions.wiggle

## loop_in

::: pymotion.expressions.loop_in

## loop_out

::: pymotion.expressions.loop_out
